echo "# $EXTENSION/build_order.txt" 				 	 > $EXTENSION/build_order.txt
echo "# <scriptname> (without .sh)" 					>> $EXTENSION/build_order.txt
echo "" 												>> $EXTENSION/build_order.txt
	
# Required
[ ! -f /lib/libtalloc.so ] && echo "Installing talloc" && extension --install talloc && echo "Finished talloc"
# Recommended
if [[ $INSTALL_OPTIONAL != false ]]; then 
	[[ $(command -v krb5-config) == "" ]] && echo "Installing mit_kerberos_v5" && extension --install mit_kerberos_v5 && echo "Finished mit_kerberos_v5"
	[[ $(command -v docutils) == "" ]] && echo "Installing py_docutils" && extension --install py_docutils && echo "Finished py_docutils"
	[[ $(command -v keyctl) == "" ]] && echo "Installing keyutils" && extension --install keyutils && echo "Finished keyutils"
	[[ $(command -v pam_namespace_helper) == "" ]] && echo "Installing linux_pam" && extension --install linux_pam && echo "Finished linux_pam"
	[[ $(command -v smbd) == "" ]] && echo "Installing samba" && extension --install samba && echo "Finished samba"
	[ ! -f /lib/pam_cap.so ] && echo "Installing libcap" && extension --install libcap && echo "Finished libcap"
fi

if [ $BUILD_ALL == "false" ] && [[ $(cat /etc/extension/installed_version.list | grep cifs_utils=7.2) == "" ]]; then
	echo "cifs_utils" 									>> $EXTENSION/build_order.txt
fi
if [ $BUILD_ALL == "true" ]; then
	echo "cifs_utils" 									>> $EXTENSION/build_order.txt
fi
echo "complete _" 										>> $EXTENSION/build_order.txt
